# Authors

The `readimc` package was developed by [Jonas Windhager](mailto:jonas.windhager@uzh.ch) based on existing functionality implemented in [imctools](https://github.com/BodenmillerGroup/imctools), which was originally created by [Vito Zanotelli](mailto:vito.zanotelli@uzh.ch) and [Anton Rau](mailto:anton.rau@uzh.ch).
